@@ -286,3 +286,37 @@ class JobLockAndWait(JobLock):
         return result
       print(self.__printmessage)
       time.sleep(self.delay)
+
+def clean_up_old_job_locks(folder, glob="*.lock_*", howold=datetime.timedelta(days=7), dryrun=False):
+  all_locks = sorted(folder.rglob(glob))
+  all_first_order_locks = sorted({filename.with_suffix(filename.suffix.split("_")[0]) for filename in all_locks})
+  locks_dict = {first_order_lock: {lock for lock in all_locks if lock.with_suffix(lock.suffix.split("_")[0]) == first_order_lock} for first_order_lock in all_first_order_locks}
+
+  remove = []
+  dontremove = []
+  for first_order_lock_file, lock_files in sorted(locks_dict.items()):
+    try:
+      modified = max(datetime.datetime.fromtimestamp(file.stat().st_mtime) for file in lock_files)
+    except FileNotFoundError:
+      dontremove.append(first_order_lock_file)
+      continue
+    now = datetime.datetime.now()
+    if now - modified < howold:
+      dontremove.append(first_order_lock_file)
+    else:
+      remove.append(first_order_lock_file)
+
+  if dryrun:
+    verb = "Would remove"
+    dontverb = "Would not remove"
+  else:
+    verb = "Removing"
+    dontverb = "Keeping"
+
+  print(f"{verb} the following locks (and their iterations):")
+  for _ in remove:
+    print(_)
+    if not dryrun:
+      with JobLock(_, corruptfiletimeout=howold): pass
+  print(f"{dontverb} the following locks (and their iterations):")
+  for _ in dontremove: print(_)
