@@ -1,5 +1,5 @@
 import contextlib, datetime, os, pathlib, subprocess, tempfile, time, unittest
-from job_lock import JobLock, JobLockAndWait, jobinfo
+from job_lock import clean_up_old_job_locks, JobLock, JobLockAndWait, jobinfo
 
 class TestJobLock(unittest.TestCase, contextlib.ExitStack):
   def __init__(self, *args, **kwargs):
@@ -139,3 +139,26 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
     self.assertFalse((self.tmpdir/"lock1.lock_5").exists())
     self.assertFalse((self.tmpdir/"lock1.lock_10").exists())
     self.assertFalse((self.tmpdir/"lock1.lock_30").exists())
+
+  def testCleanUp(self):
+    with open(self.tmpdir/"lock1.lock_2", "w") as f: pass
+    with open(self.tmpdir/"lock1.lock_5", "w") as f: pass
+    with open(self.tmpdir/"lock1.lock_30", "w") as f: pass
+    time.sleep(1)
+    with open(self.tmpdir/"lock1.lock_10", "w") as f: pass
+    clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1), dryrun=True)
+    self.assertTrue((self.tmpdir/"lock1.lock_2").exists())
+    self.assertTrue((self.tmpdir/"lock1.lock_5").exists())
+    self.assertTrue((self.tmpdir/"lock1.lock_10").exists())
+    self.assertTrue((self.tmpdir/"lock1.lock_30").exists())
+    time.sleep(1)
+    clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1), dryrun=True)
+    self.assertTrue((self.tmpdir/"lock1.lock_2").exists())
+    self.assertTrue((self.tmpdir/"lock1.lock_5").exists())
+    self.assertTrue((self.tmpdir/"lock1.lock_10").exists())
+    self.assertTrue((self.tmpdir/"lock1.lock_30").exists())
+    clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1))
+    self.assertFalse((self.tmpdir/"lock1.lock_2").exists())
+    self.assertFalse((self.tmpdir/"lock1.lock_5").exists())
+    self.assertFalse((self.tmpdir/"lock1.lock_10").exists())
+    self.assertFalse((self.tmpdir/"lock1.lock_30").exists())
